"""
Pequenas Funções utilizadas no código.
abr/2023
"""

import re


def keep_numbers(my_string):
    """
    Mantem apenas números
    '987978098098098'
    https://stackoverflow.com/questions/1249388/removing-all-non-numeric-characters-from-string-in-python

    :return: _description_
    :rtype: _type_
    """
    return re.sub('[^0-9]', '', my_string)


def find_text_between_parenthesis(my_string):
    """
    _summary_
    https://stackoverflow.com/questions/4894069/regular-expression-to-return-text-between-parenthesis

    """
    return my_string[my_string.find("(") + 1 : my_string.find(")")]


if __name__ == '__main__':
    a = keep_numbers('Michel   333  Metran')
    print(a)



"""
Meu Driver
"""

import time

from bs4 import BeautifulSoup
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.firefox.options import Options as FirefoxOptions
from selenium.webdriver.firefox.service import Service as FirefoxService
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.support.wait import WebDriverWait
from traquitanas.scrapping import adds, gecko

#from dotenv import dotenv_values, find_dotenv
#from paths import driver_path, logs_path



class Driver(webdriver.Firefox):
    """
    Cria driver customizado do Selenium

    :param webdriver: _description_
    :type webdriver: _type_
    """

    def __init__(self, my_driver_path, my_logs_path, *args, **kwargs):
        """

        verify_ssl

        :param my_driver_path: _description_
        :type my_driver_path: pathlib
        :param my_logs_path: _description_
        :type my_logs_path: pathlib
        """
        # Services
        gecko_path = gecko.get_path_geckodriver(
            my_driver_path, verify_ssl=kwargs['verify_ssl']
        )

        # Logs
        logs_filepath = my_logs_path / 'geckodriver.log'

        # Services
        my_service = FirefoxService(
            executable_path=gecko_path, log_path=logs_filepath
        )

        # Options
        my_options = FirefoxOptions()
        my_options.headless = False
        my_options.set_preference('intl.accept_languages', 'pt-BR, pt')

        # Driver
        my_driver = super(Driver, self)
        my_driver.__init__(service=my_service, options=my_options)

    def add_extension_xpath(self, my_adds_path):
        """
        Adiciona Xpath extension

        :param my_adds_path: Pasta da Extensão
        :type my_adds_path: pathlib
        """
        adds.add_extension_xpath(self, my_adds_path)

if __name__ == '__main__':
    pass


"""
Setup
"""

from setuptools import find_packages, setup

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

requirements = []
for line in open('requirements.txt', encoding='utf-8'):
    li = line.strip()
    if not li.startswith('#'):
        requirements.append(line.rstrip())

VERSION = (0, 0, 11)
__version__ = '.'.join(map(str, VERSION))

setup(
    name='sp_tjsp_divadmin',
    version=__version__,
    author='Michel Metran',
    author_email='michelmetran@gmail.com',
    description='Divisão Administrativa do TJSP, incluindo Comarcas, Cirscunscrições Judiciárias e Regiões Administrativas Judiciárias ',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/open-geodata/sp_tjsp_divadmin',
    keywords='python, dados espaciais, geoprocessamento',
    # Python and Packages
    python_requires='>=3',
    install_requires=requirements,
    # Classificação
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Natural Language :: Portuguese',
        'Intended Audience :: Developers',
    ],
    # Entry
    # package_dir={'': 'sp_bh_pcj_2020_2035'},  # Our packages live under src but src is not a package itself
    # Quando são diversos módulos...
    packages=find_packages(),
    # Dados
    include_package_data=True,
    package_data={'': ['data/output/geo/*.7z']},
)



"""
Pastas do Projeto
mar.23
"""


from pathlib import Path

project_path = Path(__file__).parents[1]
module_path = Path(__file__).parents[0]

# Data
data_path = module_path / 'data'
data_path.mkdir(exist_ok=True)

#input_path = data_path / 'input'
#input_path.mkdir(exist_ok=True)

output_path = data_path / 'output'
output_path.mkdir(exist_ok=True)

output_path_gpkg = output_path / 'gpkg'
output_path_gpkg.mkdir(exist_ok=True)

output_path_tab = output_path / 'tab'
output_path_tab.mkdir(exist_ok=True)

output_path_geo = output_path / 'geo'
output_path_geo.mkdir(exist_ok=True)

output_path_map = output_path / 'map'
output_path_map.mkdir(exist_ok=True)

# Scrapy
scrapy_path = module_path / 'scrapy'
scrapy_path.mkdir(exist_ok=True)

driver_path = scrapy_path / 'driver'
driver_path.mkdir(exist_ok=True)

logs_path = scrapy_path / 'logs'
logs_path.mkdir(exist_ok=True)

adds_path = scrapy_path / 'adds'
adds_path.mkdir(exist_ok=True)


if __name__ == '__main__':
    print(module_path)
